/*
 * Copyright (c) 2020 QMTH All Rights Reserved.
 * Created by Deason on 2020-08-31 10:24:15
 */

package cn.com.qmth.examcloud.web.filestorage.impl;

import cn.com.qmth.examcloud.commons.logging.ExamCloudLog;
import cn.com.qmth.examcloud.commons.logging.ExamCloudLogFactory;
import cn.com.qmth.examcloud.commons.util.JsonUtil;
import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.cdn.model.v20180510.RefreshObjectCachesRequest;
import com.aliyuncs.cdn.model.v20180510.RefreshObjectCachesResponse;
import com.aliyuncs.profile.DefaultProfile;

/**
 * 阿里云 - 刷新文件的CDN缓存
 */
public class AliyunRefreshCdn {

    private static final ExamCloudLog log = ExamCloudLogFactory.getLog("INTERFACE_LOGGER");

    /**
     * 刷新文件的CDN缓存：
     * 1、同一个账号 每天最多可提交2000条URL刷新和100个目录刷新
     * 2、每次请求最多只能提交1000条URL刷新，多个URL之间需要用换行符 \n 分割
     * 3、每秒最多50次请求
     */
    public static void refreshCDN(String accessKeyId, String accessKeySecret, String fileUrls) {
        DefaultProfile profile = DefaultProfile.getProfile("oss-cn-shenzhen", accessKeyId, accessKeySecret);
        IAcsClient client = new DefaultAcsClient(profile);

        RefreshObjectCachesRequest request = new RefreshObjectCachesRequest();
        request.setObjectPath(fileUrls);
        request.setObjectType("file");

        try {
            RefreshObjectCachesResponse response = client.getAcsResponse(request);

            log.info("refreshCDN fileUrl = " + fileUrls);
            if (log.isDebugEnabled()) {
                log.debug(JsonUtil.toJson(response));
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
    }

    /*public static void main(String[] args) {
        String fileUrl = "http://xxx.com/xxx/xxx.xxx";
        refreshCDN("xxx", "xxx", fileUrl);
    }*/

}
